@@ -1,11 +1,13 @@
 from datetime import datetime
 import os
 from intelab_python_tool.tools.log import log, log_init
-from flask import Flask, jsonify, request
+from flask import Flask, jsonify, request, make_response, json
 from flask.views import MethodView
 from apscheduler.schedulers.blocking import BlockingScheduler
 import requests
 import openpyxl
+import threading
+from gevent import pywsgi
 
 """
 使用方法如下：
@@ -52,9 +54,11 @@ class Monitor:
     def run(self, logs_path, host='0.0.0.0', port=5000):
         log_init('health_monitor', debug=False, log_path=logs_path)
 
-        self.api_run(host=host, port=port)
+        t1 = threading.Thread(target=self.start_scheduler)
+        t2 = threading.Thread(target=self.api_run, args=[host, port])
 
-        self.start_scheduler()
+        t1.start()
+        t2.start()
 
     @staticmethod
     def api_run(host, port):
@@ -62,28 +66,38 @@ class Monitor:
 
         @app.route('/api/ai/service_monitor', methods=['GET'])
         def get_service_health():
-            record_path = request.args.get('record_path')
-            wb = openpyxl.load_workbook(record_path)
-            ws = wb.active
-            error_times = ws['A1'].value
-            wb.close()
+            record_path_list = eval(record_paths)
+            path_fix = '/var/log/event/control_log/'
+            error_time_list = []
+            for _ in record_path_list:
+                record_path = path_fix + _ + '_monitor.xlsx'
+                wb = openpyxl.load_workbook(record_path)
+                ws = wb.actice
+                error_times = ws['C1']
+                error_time_list.append(error_times)
+                wb.close()
 
-            if error_times >= 3:
-                response = {'msg': '算法服务重启三次仍无法正常运行，请相关运维人员检查服务配置或网络', 'code': 400,
-                            'data': error_times}
+            if max(error_time_list) < 3:
+                response = {'msg': '服务正常', 'code': 200,
+                            'data': error_time_list}
+                return jsonify(response)
             else:
-                response = {'msg': '服务正常', 'code': 200, 'data': error_times}
-            return jsonify(response)
+                msg = {'msg': '服务异常'}
+                response = make_response(json.dumps(msg), 400)
+                return response
 
         # app.config['env'] = 'development'
-        app.run(host=host, port=port)
+        # app.run(host=host, port=port)
+
+        server = pywsgi.WSGIServer((host, port), app)
+        server.serve_forever()
 
     def monitor_log_run(self, service):
 
         log.info(f"本次执行健康检测的服务为{service.name}")
 
-        wb = openpyxl.load_workbook('monitor_data.xlsx')
-        ws = wb.actice
+        wb = openpyxl.load_workbook(f'/var/log/event/control_log/{service.name}_monitor.xlsx')
+        ws = wb.active
         old_data_bytes = ws['A1'].value
         check_times = ws['B1'].value
         error_times = ws['C1'].value
@@ -99,7 +113,8 @@ class Monitor:
         log.info(f'主监控日志check_times为{check_times}')
         if check_times > 3:
             log.info(f'check_times大于3，重启服务')
-            self.restart_service(service.name, service.dingtalk_function, service.restart_flag)
+            service_name = service.name if not service.restart_name else service.restart_name
+            self.restart_service(service_name, service.dingtalk_function, service.restart_flag)
             check_times = 0
             error_times += 1
         else:
@@ -112,19 +127,21 @@ class Monitor:
         if log_check != 0:
             log.info(f"{self.time}T{hour_str} 无法在日志文件中查询到，请及时查看处理")
             self.send_alarm2developer(f"{self.time}T{hour_str} 无法在日志文件中查询到，请及时查看处理", service.dingtalk_function)
-            self.restart_service(service.name, service.dingtalk_function, service.restart_flag)
+            service_name = service.name if not service.restart_name else service.restart_name
+            self.restart_service(service_name, service.dingtalk_function, service.restart_flag)
             check_times = 0
 
         ws['A1'].value = new_data_bytes
         ws['B1'].value = check_times
         ws['C1'].value = error_times
-        wb.close()
+        wb.save(f'/var/log/event/control_log/{service.name}_monitor.xlsx')
 
     def restart_service(self, service_name, ding_talk_function, restart_flag) -> None:
         if not restart_flag:
             return
-        log.info(f"正在重启{service_name}服务")
+        log.info(f"正在重启{service_name}服务, supervisorctl restart {service_name}")
         res = os.system(f"supervisorctl restart {service_name}")
+        log.info(res)
         if res == 0:
             log.info(f"重启{service_name}完成")
         else:
@@ -145,7 +162,7 @@ class Monitor:
                 ws['A1'] = 0    # 储存监控日志大小
                 ws['B1'] = 0    # 储存check_times
                 ws['C1'] = 0    # 储存error_times
-                wb.save(f'{service.name}_monitor.xlsx')
+                wb.save(f'/var/log/event/control_log/{service.name}_monitor.xlsx')
                 wb.close()
 
     def test_request(self, service):
@@ -172,14 +189,14 @@ class Monitor:
         for service in self.service_list:
             if service.monitor_type == 'l':
                 if service.scheduler_period_type == 'h':
-                    scheduler.add_job(self.monitor_log_run(service), 'interval', hours=service.scheduler_period)
+                    scheduler.add_job(self.monitor_log_run, 'interval', hours=service.scheduler_period, args=[service])
                 else:
-                    scheduler.add_job(self.monitor_log_run(service), 'interval', minutes=service.scheduler_period)
+                    scheduler.add_job(self.monitor_log_run, 'interval', minutes=service.scheduler_period, args=[service])
             elif service.monitor_type == 'a':
                 if service.scheduler_period_type == 'h':
-                    scheduler.add_job(self.test_request(service), 'interval', hours=service.scheduler_period)
+                    scheduler.add_job(self.test_request, 'interval', hours=service.scheduler_period, args=[service])
                 else:
-                    scheduler.add_job(self.test_request(service), 'interval', minutes=service.scheduler_period)
+                    scheduler.add_job(self.test_request, 'interval', minutes=service.scheduler_period, args=[service])
             else:
                 log.info(f"{service.name}服务监控类型不存在，服务监控类型目前仅支持l,a两种")
         scheduler.start()
@@ -191,18 +208,23 @@ class Monitor:
 
 class ServiceHealthApi(MethodView):
 
-    def get(self, record_path: str):
+    def get(self, record_paths: str):
+        record_path_list = eval(record_paths)
+        path_fix = '/var/log/event/control_log/'
+        error_time_list = []
+        for _ in record_path_list:
+            record_path = path_fix + _ + '_monitor.xlsx'
+            wb = openpyxl.load_workbook(record_path)
+            ws = wb.actice
+            error_times = ws['C1']
+            error_time_list.append(error_times)
+            wb.close()
 
-        wb = openpyxl.load_workbook(record_path)
-        ws = wb.actice
-        error_times = ws['C1']
-        wb.close()
-
-        if error_times >= 3:
+        if max(error_time_list) >= 3:
             response = {'msg': '算法服务重启三次仍无法正常运行，请相关运维人员检查服务配置或网络', 'code': 400,
-                        'data': error_times}
+                        'data': error_time_list}
         else:
-            response = {'msg': '服务正常', 'code': 200, 'data': error_times}
+            response = {'msg': '服务正常', 'code': 200, 'data': error_time_list}
         return jsonify(response)
 
 
@@ -216,7 +238,12 @@ class Service:
         self.scheduler_period = msg[4]
         self.dingtalk_function = msg[5]
         self.restart_flag = msg[6]
-        self.args = msg[7] if msg[7] else None
+        if len(msg) == 8:
+            self.restart_name = msg[7]
+        elif len(msg) < 8:
+            self.restart_name = 0
+        if len(msg) == 9:
+            self.args = msg[8] if msg[8] else None
 
 
 if __name__ == '__main__':
@@ -224,18 +251,53 @@ if __name__ == '__main__':
 
     @app.route('/api/ai/service_monitor', methods=['GET'])
     def get_service_health():
-        record_path = request.args.get('record_path')
-        wb = openpyxl.load_workbook(record_path)
-        ws = wb.active
-        error_times = ws['A1'].value
-        wb.close()
+        # record_path = request.args.get('record_path')
+        # wb = openpyxl.load_workbook(record_path)
+        # ws = wb.active
+        # error_times = ws['A1'].value
+        # wb.close()
 
-        if error_times >= 3:
-            response = {'msg': '算法服务重启三次仍无法正常运行，请相关运维人员检查服务配置或网络', 'code': 400,
+        error_times = 1
+
+        if error_times < 3:
+            response = {'msg': '服务正常', 'code': 200,
                         'data': error_times}
+            return jsonify(response)
         else:
-            response = {'msg': '服务正常', 'code': 200, 'data': error_times}
-        return jsonify(response)
+            msg = {'msg': '服务异常'}
+            # 构建一个response
+            response = make_response(json.dumps(msg), 400)
+            return response
 
     app.config['env'] = 'development'
     app.run(host='0.0.0.0', port=5001)
+
+    # wb = openpyxl.Workbook()
+    # ws = wb.active
+    # ws['A1'] = 1000  # 储存监控日志大小
+    # ws['B1'] = 0  # 储存check_times
+    # ws['C1'] = 0  # 储存error_times
+    # wb.save(f'test_monitor.xlsx')
+    # wb.close()
+
+    # from intelab_python_tool.tools.log import log, log_init
+    # log_init('./')
+    # wb = openpyxl.load_workbook('test_monitor.xlsx')
+    # ws = wb.active
+    # old_data_bytes = ws['A1'].value
+    # check_times = ws['B1'].value
+    # error_times = ws['C1'].value
+    # log.info(type(old_data_bytes))
+    # a = 2
+    # log.info(type(a))
+    # log.info(f'{old_data_bytes}, {check_times}, {error_times}')
+    #
+    #
+    # ws['A1'].value = 900
+    #
+    # wb.save('test_monitor.xlsx')
+
+    # a = Service([1,1,1,1,1,1,1])
+    # s = a.name if not a.restart_name else a.restart_name
+    # print(s)
+
